[][src]Enum rustc_ap_rustc_data_structures::mini_map::MiniMap

pub enum MiniMap<K, V> {
    Array(ArrayVec<[(K, V); 8]>),
    Map(FxHashMap<K, V>),
}

Small-storage-optimized implementation of a map made specifically for caching results.

Stores elements in a small array up to a certain length and switches to HashMap when that length is exceeded.

Variants

Array(ArrayVec<[(K, V); 8]>)
Map(FxHashMap<K, V>)

Implementations

impl<K: Eq + Hash, V> MiniMap<K, V>[src]

pub fn new() -> Self[src]

Creates an empty MiniMap.

pub fn insert(&mut self, key: K, value: V)[src]

Inserts or updates value in the map.

pub fn get(&self, key: &K) -> Option<&V>[src]

Return value by key if any.