[][src]Enum rustc_ap_rustc_data_structures::mini_set::MiniSet

pub enum MiniSet<T> {
    Array(ArrayVec<[T; 8]>),
    Set(FxHashSet<T>),
}

Small-storage-optimized implementation of a set.

Stores elements in a small array up to a certain length and switches to HashSet when that length is exceeded.

Variants

Array(ArrayVec<[T; 8]>)
Set(FxHashSet<T>)

Implementations

impl<T: Eq + Hash> MiniSet<T>[src]

pub fn new() -> Self[src]

Creates an empty MiniSet.

pub fn insert(&mut self, elem: T) -> bool[src]

Adds a value to the set.

If the set did not have this value present, true is returned.

If the set did have this value present, false is returned.